@@ -13,17 +13,21 @@
 # under the License.
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Callable
+from typing import TYPE_CHECKING, Callable, Union, Optional, Any, Awaitable, Dict
 
 from . import exceptions as ex
 from . import utils
 from .emaildelivery import services as emaildelivery_services
+from . import recipe
+from .interfaces import TypeGetEmailForUserIdFunction
 from .recipe import EmailVerificationRecipe
+from .types import EmailTemplateVars, User
+from ...ingredients.emaildelivery.types import EmailDeliveryConfig
 
 InputOverrideConfig = utils.OverrideConfig
-ParentRecipeEmailVerificationConfig = utils.ParentRecipeEmailVerificationConfig
 exception = ex
 SMTPService = emaildelivery_services.SMTPService
+EmailVerificationClaim = recipe.EmailVerificationClaim
 
 
 if TYPE_CHECKING:
@@ -31,8 +35,22 @@ if TYPE_CHECKING:
 
     from ...recipe_module import RecipeModule
 
+from .utils import MODE_TYPE, OverrideConfig
+
 
 def init(
-    config: ParentRecipeEmailVerificationConfig,
+    mode: MODE_TYPE,
+    email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None,
+    get_email_for_user_id: Optional[TypeGetEmailForUserIdFunction] = None,
+    create_and_send_custom_email: Union[
+        Callable[[User, str, Dict[str, Any]], Awaitable[None]], None
+    ] = None,
+    override: Union[OverrideConfig, None] = None,
 ) -> Callable[[AppInfo], RecipeModule]:
-    return EmailVerificationRecipe.init(config)
+    return EmailVerificationRecipe.init(
+        mode,
+        email_delivery,
+        get_email_for_user_id,
+        create_and_send_custom_email,
+        override,
+    )
